====================
 Invenio-Ext v0.2.1
====================

Invenio-Ext v0.2.1 was released on September 23, 2015.

About
-----

Invenio module that provides integration with Flask extensions.

*This is an experimental developer preview release.*

Incompatible changes
--------------------

- Removes previously disabled legacy handlers.

Bug fixes
---------

- Adds missing MySQL-python>=1.2.5 dependency.

Installation
------------

   $ pip install invenio-ext==0.2.1

Documentation
-------------

   http://invenio-ext.readthedocs.org/en/v0.2.1

Happy hacking and thanks for flying Invenio-Ext.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-ext
|   URL: http://invenio-software.org
